#
# spec file for package ghc-toml-parser
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name toml-parser
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.0.1.2
Release:        1.1
Summary:        TOML 1.0.0 parser
License:        ISC
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  alex
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-prettyprinter-devel
BuildRequires:  ghc-prettyprinter-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  happy
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
%endif

%description
TOML parser using generated lexers and parsers with careful attention to the
TOML 1.0.0 semantics for defining tables.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Apr 30 2025 Peter Simons <psimons@suse.com>
- Update toml-parser to version 2.0.1.2.
  [#]# 2.0.1.2
  * Reject inputs with out-of-bounds time zone offsets in accordance
    with the toml-tests test suite.
  [#]# 2.0.1.1
  * Fixes bug that prohibited non-ASCII characters in `'''` strings.
* Thu Dec 19 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 2.0.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri May 31 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 2.0.1.0.
  [#]# 2.0.1.0
  * Added `ToValue UTCTime` and `FromValue UTCTime`. These correspond
    to offset data-times with the timezone translated to UTC.
* Mon May 13 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 2.0.0.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Mar 22 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 2.0.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Feb 26 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 2.0.0.0.
  [#]# 2.0.0.0
  * Pervasive annotations on the values added to allow for detailed
    positional error reporting throughout parsing and validation.
  * Replace uses of String with Text in the Value type and throughout
    the API
  * Reorganized almost all of the modules to minimize imports that upstream
    packages will actually need.
  [#]# 1.3.3.0
  * Added `IsString Value` instance.
  * Addded helpers for `runMatcher` for ignoring and failing on warning
    `runMatcherIgnoreWarn` and `runMatcherFatalWarn`
* Mon Jan 15 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 1.3.2.0.
  [#]# 1.3.2.0
  * Added `Toml.Generic` to make instances easily derivable via DerivingVia.
  * Added GHC.Generics support for switching between product types and TOML arrays.
* Wed Jan 10 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 1.3.1.3.
  [#]# 1.3.1.3
  * Bugfix: Previous fix admitted some invalid inline tables - these are now rejected
* Fri Jan  5 2024 Peter Simons <psimons@suse.com>
- Update toml-parser to version 1.3.1.2.
  [#]# 1.3.1.2
  * Bugfix: In some cases overlapping keys in inline tables could throw an exception
    instead instead of returning the proper semantic error value.
* Sat Dec  9 2023 Peter Simons <psimons@suse.com>
- Update toml-parser to version 1.3.1.1.
  [#]# 1.3.1.1
  * Ensure years are rendered zero-padded
* Tue Nov 28 2023 Peter Simons <psimons@suse.com>
- Update toml-parser to version 1.3.1.0.
  [#]# 1.3.1.0
  * Added `Toml.Semantics.Ordered` for preserving input TOML orderings
  * Added support for pretty-printing multi-line strings
* Sun Jul 16 2023 Peter Simons <psimons@suse.com>
- Add toml-parser at version 1.3.0.0.
